.. _all-salt.modules:

=================
execution modules
=================

.. admonition:: Virtual modules

    .. toctree::

        salt.modules.group
        salt.modules.kernelpkg
        salt.modules.pkg
        salt.modules.service
        salt.modules.shadow
        salt.modules.sysctl
        salt.modules.user

.. currentmodule:: salt.modules

.. autosummary::
    :toctree:
    :template: autosummary.rst.tmpl

    aix_group
    aix_shadow
    aixpkg
    aliases
    alternatives
    ansiblegate
    apache
    apf
    aptpkg
    archive
    arista_pyeapi
    artifactory
    asymmetric
    at
    at_solaris
    baredoc
    bcache
    beacons
    bridge
    cassandra_cql
    celery
    chef
    chocolatey
    chronos
    chroot
    cloud
    cmdmod
    config
    cp
    cron
    cryptdev
    data
    debconfmod
    debian_ip
    debian_service
    debuild_pkgbuild
    defaults
    devinfo
    devmap
    dig
    disk
    dnsutil
    dpkg_lowpkg
    dummyproxy_pkg
    dummyproxy_service
    environ
    etcd_mod
    ethtool
    event
    extfs
    file
    firewalld
    git
    gpg
    grains
    groupadd
    hashutil
    highstate_doc
    hosts
    http
    idem
    incron
    ini_manage
    iosconfig
    ipset
    iptables
    iwtools
    jinja
    junos
    kernelpkg_linux_apt
    kernelpkg_linux_yum
    key
    keyboard
    kmod
    linux_acl
    linux_ip
    linux_lvm
    linux_service
    linux_shadow
    linux_sysctl
    localemod
    locate
    logmod
    logrotate
    mac_assistive
    mac_brew_pkg
    mac_desktop
    mac_group
    mac_keychain
    mac_pkgutil
    mac_portspkg
    mac_power
    mac_service
    mac_shadow
    mac_softwareupdate
    mac_sysctl
    mac_system
    mac_timezone
    mac_user
    mac_xattr
    macdefaults
    macpackage
    match
    mdadm_raid
    mine
    minion
    mod_random
    mount
    mysql
    nacl
    napalm_bgp
    napalm_formula
    napalm_mod
    napalm_netacl
    napalm_network
    napalm_ntp
    napalm_probes
    napalm_route
    napalm_snmp
    napalm_users
    napalm_yang_mod
    netaddress
    network
    nfs3
    nftables
    nixpkg
    npm
    nxos
    nxos_api
    nxos_upgrade
    oracle
    osquery
    out
    pacmanpkg
    pam
    parted_partition
    pillar
    pip
    pkg_resource
    pkgin
    pkgng
    pkgutil
    postgres
    proxy
    ps
    publish
    puppet
    pw_group
    pw_user
    pyenv
    quota
    rabbitmq
    rbac_solaris
    rdp
    reg
    rest_pkg
    rest_sample_utils
    rest_service
    restartcheck
    ret
    rh_ip
    rh_service
    rpm_lowpkg
    rpmbuild_pkgbuild
    rsync
    salt_proxy
    salt_version
    saltcheck
    saltcloudmod
    saltutil
    schedule
    scp_mod
    scsi
    sdb
    seed
    selinux
    slack_notify
    slsutil
    smbios
    smf_service
    snapper
    solaris_fmadm
    solaris_group
    solaris_shadow
    solaris_system
    solaris_user
    solarisipspkg
    solarispkg
    sqlite3
    ssh
    ssh_pkg
    ssh_pki
    ssh_service
    state
    status
    supervisord
    sysfs
    syslog_ng
    sysmod
    system
    systemd_service
    temp
    test
    test_virtual
    textfsm_mod
    timezone
    tls
    udev
    upstart_service
    useradd
    vagrant
    virtualenv_mod
    vsphere
    webutil
    win_appx
    win_auditpol
    win_autoruns
    win_certutil
    win_dacl
    win_disk
    win_dism
    win_dns_client
    win_dsc
    win_event
    win_file
    win_firewall
    win_groupadd
    win_iis
    win_ip
    win_lgpo
    win_lgpo_reg
    win_license
    win_network
    win_ntp
    win_path
    win_pkg
    win_pki
    win_powercfg
    win_psget
    win_servermanager
    win_service
    win_shadow
    win_shortcut
    win_smtp_server
    win_snmp
    win_status
    win_system
    win_task
    win_timezone
    win_useradd
    win_wua
    win_wusa
    winrepo
    x509
    x509_v2
    xfs
    xml
    yaml
    yumpkg
    zk_concurrency
    zoneadm
    zonecfg
